@@ -5,6 +5,7 @@ OC.L10N.register(
     "All contacts" : "Alle kontakte",
     "Details" : "Details",
     "A contacts app for Nextcloud" : "’n Kontakte-toep vir Nextcloud",
+    "Loading" : "Laai tans..",
     "Name" : "Naam",
     "Company" : "Maatskappy",
     "Title" : "Titel",
@@ -15,6 +16,7 @@ OC.L10N.register(
     "New contact" : "Nuwe kontak",
     "Select type" : "Kies tipe",
     "Select Date" : "Kies Datum",
+    "Last modified" : "Laas gewysig",
     "Select option" : "Kies opsie",
     "Rename" : "Hernoem",
     "Copied" : "Gekopieer",
@@ -22,9 +24,12 @@ OC.L10N.register(
     "Copy link" : "Kopieer skakel",
     "Share with users or groups" : "Deel met gebruikers of groepe",
     "No users or groups" : "Geen gebruikers of groepe",
+    "can edit" : "kan wysig",
+    "Address book name" : "Adresboeknaam",
     "First name" : "Naam",
     "Last name" : "Van",
     "Display name" : "Vertoonnaam",
+    "Not grouped" : "Nie gegroepeer",
     "Nickname" : "Bynaam",
     "Detailed name" : "Gedetailleerde naam",
     "Additional names" : "Addisionele name",
@@ -32,6 +37,7 @@ OC.L10N.register(
     "Suffix" : "Agtervoegsel",
     "Notes" : "Notas",
     "Website" : "Webwerf",
+    "Location" : "Ligging",
     "Federated Cloud ID" : "Gefedereerde Wolk-ID",
     "Home" : "Tuis",
     "Work" : "Werk",
@@ -80,6 +86,9 @@ OC.L10N.register(
     "Gender" : "Geslag",
     "Female" : "Vroulik",
     "Male" : "Manlik",
+    "None" : "Geen",
+    "Unknown" : "Onbekend",
+    "Timezone" : "Tydsone",
     "An error occurred" : "'n Fout het voorgekom"
 },
 "nplurals=2; plural=(n != 1);");
