@@ -8,6 +8,7 @@ OC.L10N.register(
     "Upload a new picture" : "تحميل صورة جديدة",
     "Delete picture" : "حذف الصورة",
     "Download picture" : "تنزيل الصورة",
+    "Loading" : "Loading",
     "Name" : "الاسم",
     "Company" : "الشركة",
     "Title" : "العنوان",
@@ -16,13 +17,22 @@ OC.L10N.register(
     "Addressbook" : "دفتر العناوين",
     "Groups" : "مجموعات",
     "New contact" : "جهة إتصال جديدة",
+    "No errors" : "لا توجد أخطاء",
+    "No results" : "دون أية نتيجة",
+    "Last modified" : "آخر تعديل",
     "Rename" : "تعديل الإسم",
+    "Enabled" : "مفعلة",
+    "Disabled" : "معطّل",
     "Copy link" : "نسخ الرابط",
     "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
+    "can edit" : "يمكن التعديل",
+    "Importing into" : "إستيراد إلى",
     "Import into" : "إستيراد إلى",
     "Address book name" : "اسم دفتر العناوين",
     "First name" : "الإسم",
     "Last name" : "اللقب",
+    "Display name" : "الاسم المعروض",
+    "Not grouped" : "غير مصنف",
     "Nickname" : "كنية.\nلقب.",
     "Detailed name" : "الإسم بالتفصيل",
     "Additional names" : "الأسماء الإضافية",
@@ -30,6 +40,7 @@ OC.L10N.register(
     "Suffix" : "لاحقة",
     "Notes" : "الملاحظات",
     "Website" : "موقع إلكتروني",
+    "Location" : "المكان",
     "Federated Cloud ID" : "معرّف السحابة الخارجية",
     "Home" : "المنزل",
     "Work" : "العمل",
@@ -52,6 +63,11 @@ OC.L10N.register(
     "Fax work" : "فاكس العمل",
     "Pager" : "النداء",
     "Voice" : "صوت",
-    "Social network" : "شبكة اجتماعية"
+    "Social network" : "شبكة اجتماعية",
+    "Relative" : "مرتبط",
+    "None" : "لا شيء",
+    "Unknown" : "مجهول",
+    "Timezone" : "المنطقة الزمنية",
+    "An error occurred" : "طرأ هناك خطأ"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
