@@ -4,15 +4,25 @@ OC.L10N.register(
     "Contacts" : "Contautos",
     "All contacts" : "Tolos contautos",
     "Details" : "Detalles",
+    "Loading" : "Cargando",
+    "Name" : "Nome",
+    "Title" : "Títulu",
     "Download" : "Baxar",
     "Delete" : "Desaniciar",
     "Groups" : "Grupos",
     "New contact" : "Contautu nuevu",
+    "No results" : "Ensin resultaos",
     "Rename" : "Renomar",
+    "Enabled" : "Habilitar",
+    "Disabled" : "Deshabilitáu",
     "Copy link" : "Copiar enllaz",
     "Share with users or groups" : "Compartir con usuarios y grupos",
+    "can edit" : "pue editar",
+    "Address book name" : "Nome de la Llibreta de direiciones",
     "First name" : "Nome",
     "Last name" : "Apellíu",
+    "Display name" : "Nome",
+    "Not grouped" : "Nun s'agrupó",
     "Nickname" : "Nomatu",
     "Detailed name" : "Nome detalláu",
     "Additional names" : "Nomes adicionales",
@@ -20,6 +30,7 @@ OC.L10N.register(
     "Suffix" : "Sufixu",
     "Notes" : "Notes",
     "Website" : "Sitiu web",
+    "Location" : "Llocalización",
     "Federated Cloud ID" : "ID de ñube federada",
     "Home" : "Casa",
     "Work" : "Trabayu",
@@ -42,6 +53,10 @@ OC.L10N.register(
     "Fax work" : "Fax del trabayu",
     "Pager" : "Llocalizador",
     "Voice" : "Voz",
-    "Social network" : "Rede social"
+    "Social network" : "Rede social",
+    "Relative" : "Relativu",
+    "Contact" : "Contautu",
+    "None" : "Dengún",
+    "Unknown" : "Desconozse"
 },
 "nplurals=2; plural=(n != 1);");
