@@ -2,14 +2,27 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "পরিচিতজন",
+    "Details" : "বিসতারিত",
+    "Loading" : "Loading",
+    "Name" : "নাম",
+    "Title" : "শিরোনাম",
+    "Download" : "ডাউনলোড",
+    "Delete" : "মুছে",
     "Groups" : "গোষ্ঠীসমূহ",
     "New contact" : "নতুন ঠিকানা",
+    "Rename" : "পূনঃনামকরণ",
+    "Enabled" : "কার্যকর",
+    "Disabled" : "অকার্যকর",
+    "Copy link" : "লিঙ্ক কপি করো",
+    "can edit" : "সম্পাদনা করতে পারবেন",
     "First name" : "নামের প্রথমাংশ ",
     "Last name" : "নামের শেষাংশ",
+    "Not grouped" : "দলবদ্ধ নয়",
     "Nickname" : "ছদ্মনাম",
     "Additional names" : "অতিরিক্ত নামসমূহ",
     "Notes" : "নোট",
     "Website" : "ওয়েবসাইট",
+    "Location" : "অবস্থান",
     "Home" : "নিবাস",
     "Work" : "কর্মস্থল",
     "Other" : "অন্যান্য",
@@ -25,6 +38,8 @@ OC.L10N.register(
     "Mobile" : "মোবাইল",
     "Fax" : "ফ্যাক্স",
     "Pager" : "পেজার",
-    "Voice" : "কন্ঠ"
+    "Voice" : "কন্ঠ",
+    "None" : "কোনটিই নয়",
+    "Unknown" : "অজানা"
 },
 "nplurals=2; plural=(n != 1);");
