@@ -6,9 +6,13 @@ OC.L10N.register(
     "Details" : "Detalles",
     "A contacts app for Nextcloud" : "Una aplicación de contactos para Nextcloud",
     "Copy to full name" : "Copiar a nombre completo",
+    "Omit year" : "Omitir año",
     "Add new property" : "Añadir nueva propiedad",
     "Choose property type" : "Elija el tipo de propiedad",
+    "Add a new picture" : "Agregar una nueva foto",
     "Upload a new picture" : "Subir una nueva imagen",
+    "Choose from files" : "Elige entre archivos",
+    "Download picture" : "Descargar imágen",
     "Image is too big (max 1MB)." : "La imagen es demasiado grande (máximo 1MB).",
     "No contact selected" : "Contacto no seleccionado",
     "Select a contact on the list to begin" : "Seleccione un contacto en la lista para comenzar",
@@ -17,6 +21,7 @@ OC.L10N.register(
     "Company" : "Empresa",
     "Title" : "Título",
     "Download" : "Descargar",
+    "Generate QR Code" : "Generar código QR",
     "Delete" : "Borrar",
     "This contact is not yet synced. Edit it to save it to the server." : "Este contacto aún no está sincronizado. Edítalo para guardarlo en el servidor.",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "Este contacto está en modo de sólo lectura. No tienes permiso para editar este contacto.",
@@ -25,11 +30,13 @@ OC.L10N.register(
     "Groups" : "Grupos",
     "New contact" : "Nuevo contacto",
     "Importing {total} contacts into" : "Importando {total} contactos a",
+    "No errors" : "Sin errores",
     "Open your browser console for more details" : "Abra la consola de su navegador para más detalles",
     "Select type" : "Seleccionar tipo",
     "Select Date" : "Seleccionar fecha",
     "Add contact in group" : "Añadir contacto en grupo",
     "No results" : "Sin resultados",
+    "Last modified" : "Última modificación",
     "Select option" : "Seleccionar opción",
     "Rename" : "Renombrar",
     "Enabled" : "Habilitado",
@@ -58,6 +65,7 @@ OC.L10N.register(
     "Last name" : "Apellido",
     "Display name" : "Nombre para mostrar",
     "Sort by {sorting}" : "Ordenar por {sorting}",
+    "Not grouped" : "No agrupado",
     "Unable to create the contact." : "No se puede crear el contacto.",
     "Contact not found" : "Contacto no encontrado",
     "Nickname" : "Apodo",
@@ -67,6 +75,7 @@ OC.L10N.register(
     "Suffix" : "Sufijo",
     "Notes" : "Notas",
     "Website" : "Sitio web",
+    "Location" : "Ubicación",
     "Federated Cloud ID" : "Id de nube federada",
     "Home" : "Particular",
     "Work" : "Trabajo",
@@ -119,6 +128,9 @@ OC.L10N.register(
     "Gender" : "Género",
     "Female" : "Femenino",
     "Male" : "Masculino",
+    "None" : "Ninguno",
+    "Unknown" : "Desconocido",
+    "Timezone" : "Zona horaria",
     "An error occurred" : "Ocurrió un error"
 },
 "nplurals=2; plural=(n != 1);");
