@@ -4,18 +4,28 @@ OC.L10N.register(
     "Contacts" : "Kontaktid",
     "All contacts" : "Kõik kontaktid",
     "Details" : "Üksikasjad",
+    "Loading" : "Laadimine",
+    "Name" : "Nimi",
+    "Title" : "Pealkiri",
     "Download" : "Lae alla",
     "Delete" : "Kustuta",
     "Groups" : "Grupid",
     "New contact" : "Uus kontakt",
+    "No results" : "Vasteid ei leitud",
+    "Last modified" : "Viimati muudetud",
     "Rename" : "Nimeta ümber",
     "Enabled" : "Lubatud",
     "Disabled" : "Keelatud",
     "Copy link" : "Kopeeri link",
     "Share with users or groups" : "Jaga kasutajate või gruppidega",
+    "can edit" : "saab redigeerida",
+    "Importing into" : "Importimine sisse",
     "Import into" : "import sisse",
+    "Address book name" : "Aadressiraamatu nimi",
     "First name" : "Eesnimi",
     "Last name" : "Perekonnanimi",
+    "Display name" : "Kuvatav nimi",
+    "Not grouped" : "Pole grupeeritud",
     "Nickname" : "Hüüdnimi",
     "Detailed name" : "Üksikasjalik nimi",
     "Additional names" : "Lisanimed",
@@ -23,6 +33,7 @@ OC.L10N.register(
     "Suffix" : "Järelliide",
     "Notes" : "Märkmed",
     "Website" : "Veebileht",
+    "Location" : "Asukoht",
     "Federated Cloud ID" : "Liitpilve ID",
     "Home" : "Kodu",
     "Work" : "Töö",
@@ -62,8 +73,11 @@ OC.L10N.register(
     "Colleague" : "Kolleeg",
     "Manager" : "Juht",
     "Assistant" : "Assistent",
+    "Contact" : "Kontakt",
     "Gender" : "Sugu",
     "Female" : "Naine",
-    "Male" : "Mees"
+    "Male" : "Mees",
+    "None" : "Pole",
+    "Unknown" : "Teadmata"
 },
 "nplurals=2; plural=(n != 1);");
