@@ -4,6 +4,7 @@ OC.L10N.register(
     "Contacts" : "Kontaktuak",
     "All contacts" : "Kontaktu guztiak",
     "Details" : "Xehetasuna",
+    "Add new property" : "Gehitu propietate berria",
     "No contact selected" : "Ez dago kontakturik hautatuta",
     "Select a contact on the list to begin" : "Hautatu zerrendako kontaktu bat lanean hasteko",
     "Loading" : "Kargatzen",
@@ -15,22 +16,34 @@ OC.L10N.register(
     "Addressbook" : "Helbide-liburua",
     "Groups" : "Taldeak",
     "New contact" : "Kontaktu berria",
+    "No errors" : "Errorerik ez",
+    "Open your browser console for more details" : "Ireki nabigatzailearen kontsola xehetasun gehiagorako",
     "Select type" : "Hautatu mota",
     "Select Date" : "Hautatu data",
     "Add contact in group" : "Gehitu kontaktua taldera",
     "No results" : "Emaitzarik ez",
+    "Last modified" : "Azken aldaketa",
     "Rename" : "Aldatu izena",
+    "Enabled" : "Gaitua",
+    "Disabled" : "Desaktibatua",
     "Copied" : "Kopiatuta",
     "Can not copy" : "Ezin da kopiatu",
     "Copy link" : "Esteka kopiatu",
+    "Delete {addressbook} ?" : "Ezabatu {addressbook} ?",
     "Addressbook was not copied to clipboard." : "Helbide-liburua ez da arbelera kopiatu",
     "Share with users or groups" : "Erabiltzaile edo taldeekin partekatu",
     "No users or groups" : "Erabiltzaile edo talderik ez",
+    "can edit" : "edita daiteke",
+    "Unable to delete the share." : "Ezin da partekatzea ezabatu.",
+    "Unable to change permissions." : "Ezin dira baimenak aldatu.",
+    "Importing into" : "Informazioa inportatzen",
     "Import into" : "Inportatu hona",
+    "Address book name" : "Agenda izena",
     "An error occurred, unable to create the addressbook." : "Errorea gertatu da, ezin izan da helbide-liburua sortu.",
     "First name" : "Izena",
     "Last name" : "Abizena",
     "Display name" : "Pantaila-izena",
+    "Not grouped" : "Taldekatu gabe",
     "Contact not found" : "Kontaktua ez da aurkitu",
     "Nickname" : "Ezizena",
     "Detailed name" : "Izen osoa",
@@ -39,6 +52,7 @@ OC.L10N.register(
     "Suffix" : "Atzizkia",
     "Notes" : "Oharrak",
     "Website" : "Webgunea",
+    "Location" : "Kokapena",
     "Federated Cloud ID" : "Federatutatako Hodei ID",
     "Home" : "Etxekoa",
     "Work" : "Lanekoa",
@@ -81,10 +95,14 @@ OC.L10N.register(
     "Colleague" : "Lankidea",
     "Manager" : "Jefea",
     "Assistant" : "Asistentea",
+    "Contact" : "Kontaktua",
     "Emergency" : "Larrialdia",
     "Gender" : "Generoa",
     "Female" : "Emakumea",
     "Male" : "Gizonezkoa",
+    "None" : "Bat ere ez",
+    "Unknown" : "Ezezaguna",
+    "Timezone" : "Ordu-zona",
     "An error occurred" : "Errorea gertatu da"
 },
 "nplurals=2; plural=(n != 1);");
