@@ -4,16 +4,30 @@ OC.L10N.register(
     "Contacts" : "مخاطبین",
     "All contacts" : "تمام مخاطبین",
     "Details" : "جزئیات",
+    "Loading" : "در حال بار گزاری",
+    "Name" : "نام",
+    "Company" : "شرکت",
+    "Title" : "عنوان",
     "Download" : "دانلود",
     "Delete" : "حذف",
     "Groups" : "گروه ها",
     "New contact" : "مخاطب جدید",
+    "No results" : "نتیجه ای یافت نشد",
+    "Last modified" : "آخرین اصلاح شده",
     "Rename" : "تغییرنام",
+    "Enabled" : "فعال شده",
+    "Disabled" : "غیرفعال شده",
     "Copy link" : "کپی کردن لینک",
     "Share with users or groups" : "اشتراک گذاری با کاربران یا گروه ها ...",
+    "No users or groups" : "هیچ کاربر یا گروهی وجود ندارد",
+    "can edit" : "توانایی ویرایش",
+    "Importing into" : "در حال وارد کردن به",
     "Import into" : "وارد کردن به",
+    "Address book name" : "نام دفترچه آدرس",
     "First name" : "نام",
     "Last name" : "نام‌خانوادگی",
+    "Display name" : "نام جهت نمایش",
+    "Not grouped" : "گروه بندی نشده",
     "Nickname" : "نام مستعار",
     "Detailed name" : "نام کامل",
     "Additional names" : "نام های دیگر",
@@ -21,6 +35,7 @@ OC.L10N.register(
     "Suffix" : "پسوند",
     "Notes" : "یادداشت ها",
     "Website" : "وب‌سایت",
+    "Location" : "محل",
     "Federated Cloud ID" : "Federated Cloud شناسه",
     "Home" : "خانه",
     "Work" : "کار",
@@ -57,8 +72,11 @@ OC.L10N.register(
     "Colleague" : "کالج",
     "Manager" : "مدیر",
     "Assistant" : "راهنما",
+    "Contact" : "مخاطب",
     "Gender" : "جنسیت",
     "Female" : "مؤنث",
-    "Male" : "مذکر"
+    "Male" : "مذکر",
+    "None" : "هیچ‌کدام",
+    "Unknown" : "نامشخص"
 },
 "nplurals=2; plural=(n > 1);");
