@@ -3,13 +3,24 @@ OC.L10N.register(
     {
     "Contacts" : "Contactos",
     "All contacts" : "Tote contactos",
+    "Details" : "Detalios",
+    "Loading" : "Loading",
+    "Name" : "Nomine",
+    "Title" : "Titulo",
     "Download" : "Discargar",
     "Delete" : "Deler",
     "Groups" : "Gruppos",
     "New contact" : "Nove contacto",
+    "Rename" : "Renominar",
+    "Enabled" : "Activate",
+    "Copy link" : "Copiar ligamine",
     "Share with users or groups" : "Compartir con usatores o gruppos",
+    "can edit" : "pote modificar",
+    "Address book name" : "Nomine del adressario",
     "First name" : "Prime nomine",
     "Last name" : "Ultime nomine",
+    "Display name" : "Monstrar nomine",
+    "Not grouped" : "Non gruppate",
     "Nickname" : "Pseudonymo",
     "Detailed name" : "Nomine detaliate",
     "Additional names" : "Nomines additional",
@@ -17,6 +28,7 @@ OC.L10N.register(
     "Suffix" : "Suffixo",
     "Notes" : "Notas",
     "Website" : "Sito web",
+    "Location" : "Loco",
     "Federated Cloud ID" : "ID del Nube Federate",
     "Home" : "Domo",
     "Work" : "Travalio",
@@ -39,6 +51,9 @@ OC.L10N.register(
     "Fax work" : "Fax a travalio",
     "Pager" : "Pager",
     "Voice" : "Voce",
-    "Social network" : "Medios Social"
+    "Social network" : "Medios Social",
+    "Relative" : "Relative",
+    "None" : "Nulle",
+    "Unknown" : "Incognite"
 },
 "nplurals=2; plural=(n != 1);");
