@@ -3,13 +3,27 @@ OC.L10N.register(
     {
     "Contacts" : "Kontak",
     "All contacts" : "Semua kontak",
+    "Details" : "Detil",
+    "Loading" : "Memuat",
+    "Name" : "Nama",
+    "Title" : "Judul",
     "Download" : "Unduh",
     "Delete" : "Hapus",
     "Groups" : "Grup",
     "New contact" : "Kontak baru",
+    "No results" : "Tidak ada hasil",
+    "Last modified" : "Terakhir diubah",
+    "Rename" : "Ubah nama",
+    "Enabled" : "Diaktifkan",
+    "Disabled" : "Dinonaktifkan",
+    "Copy link" : "Salin tautan",
     "Share with users or groups" : "Bagi dengan pengguna atau grup",
+    "can edit" : "dapat menyunting",
+    "Address book name" : "Nama buku alamat",
     "First name" : "Nama depan",
     "Last name" : "Nama belakang",
+    "Display name" : "Nama tampilan",
+    "Not grouped" : "Tidak dikelompokkan",
     "Nickname" : "Nama panggilan",
     "Detailed name" : "Nama lengkap",
     "Additional names" : "Nama tambahan",
@@ -17,6 +31,7 @@ OC.L10N.register(
     "Suffix" : "Suffix",
     "Notes" : "Catatan",
     "Website" : "Situs Web",
+    "Location" : "Lokasi",
     "Federated Cloud ID" : "Federated Cloud ID",
     "Home" : "Depan",
     "Work" : "Kantor",
@@ -39,6 +54,8 @@ OC.L10N.register(
     "Fax work" : "Fax kerja",
     "Pager" : "Pager",
     "Voice" : "Suara",
-    "Social network" : "Media sosial"
+    "Social network" : "Media sosial",
+    "None" : "Tidak ada",
+    "Unknown" : "Tidak diketahui"
 },
 "nplurals=1; plural=0;");
