@@ -24,6 +24,7 @@ OC.L10N.register(
     "Name" : "名前",
     "Company" : "会社",
     "Title" : "タイトル",
+    "This contact was broken and received a fix. Please review the content and click here to save it." : "この連絡先は変更され、修正を受信しました。内容を確認してクリックで保存してください。",
     "Download" : "ダウンロード",
     "Generate QR Code" : "QRコードを生成",
     "Delete" : "削除",
@@ -84,6 +85,7 @@ OC.L10N.register(
     "Suffix" : "サフィックス",
     "Notes" : "ノート",
     "Website" : "ウェブサイト",
+    "Location" : "場所",
     "Federated Cloud ID" : "クラウド共有ID",
     "Home" : "自宅",
     "Work" : "職場",
@@ -139,6 +141,8 @@ OC.L10N.register(
     "Male" : "男性",
     "None" : "なし",
     "Unknown" : "不明",
+    "Timezone" : "タイムゾーン",
+    "Spoken languages" : "話せる言語",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed}連絡先の読み込みができませんでした。"],
     "An error occurred" : "エラーが発生しました",
     "Your web browser is out of date" : "ウェブブラウザが古いです",
