@@ -83,6 +83,7 @@ OC.L10N.register(
     "Suffix" : "접미사",
     "Notes" : "메모",
     "Website" : "웹 사이트",
+    "Location" : "위치",
     "Federated Cloud ID" : "연합 클라우드 ID",
     "Home" : "가정",
     "Work" : "직장",
@@ -138,6 +139,7 @@ OC.L10N.register(
     "Male" : "남성",
     "None" : "없음",
     "Unknown" : "알 수 없음",
+    "Timezone" : "시간대",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["연락처 {failed}개를 읽을 수 없음"],
     "An error occurred" : "오류가 발생함",
     "Your web browser is out of date" : "웹 브라우저가 오래되었습니다",
