@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "Contacts" : "Adresatai",
     "All contacts" : "Visi adresatai",
+    "Details" : "Išsamiau",
     "A contacts app for Nextcloud" : "Adresatų programėlė, skirta Nextcloud",
     "Copy to full name" : "Kopijuoti į vardą, pavardę",
     "Add new property" : "Pridėti naują savybę",
@@ -35,7 +36,9 @@ OC.L10N.register(
     "Deleting the contact in {countdown} seconds" : "Adresatas ištrinamas po {countdown} sek.",
     "No errors" : "Klaidų nėra",
     "Open your browser console for more details" : "Išsamesnei informacijai, atverkite savo naršyklės pultą",
+    "Add contact in group" : "Pridėti adresatą į grupę",
     "No results" : "Rezultatų nėra",
+    "Last modified" : "Paskutinis modifikavimas",
     "Select option" : "Pasirinkite parinktį",
     "Rename" : "Pervadinti",
     "Enabled" : "Įjungta",
@@ -49,11 +52,13 @@ OC.L10N.register(
     "Renaming of addressbook was not successful." : "Adresų knygos pervadinimas buvo nesėkmingas.",
     "Addressbook copied to clipboard" : "Adresų knyga nukopijuota į iškarpinę",
     "Addressbook was not copied to clipboard." : "Adresų knyga nebuvo nukopijuota į iškarpinę.",
+    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Bendrinama su {num} esybe","Bendrinama su {num} esybėmis","Bendrinama su {num} esybių","Bendrinama su {num} esybe"],
     "Share with users or groups" : "Bendrinti su naudotojais ar grupėmis",
     "No users or groups" : "Nėra jokių naudotojų ar grupių",
     "can edit" : "gali redaguoti",
     "Unable to delete the share." : "Nepavyko ištrinti viešinio.",
     "Unable to change permissions." : "Nepavyko pakeisti leidimų.",
+    "Importing into" : "Importuojama į",
     "Import into" : "Importuoti į",
     "Importing is disabled because there are no address books available" : "Importavimas yra išjungtas, nes nėra prieinamų adresų knygų",
     "Address book name" : "Adresų knygos pavadinimas",
@@ -115,6 +120,7 @@ OC.L10N.register(
     "Colleague" : "Bendradarbiai",
     "Manager" : "Vadovas",
     "Assistant" : "Asistentas",
+    "Contact" : "Adresatas",
     "Co-worker" : "Bendradarbis",
     "Gender" : "Lytis",
     "Female" : "Moteris",
