@@ -4,19 +4,31 @@ OC.L10N.register(
     "Contacts" : "Харилцагчид",
     "All contacts" : "Бүх харилцагчид",
     "Details" : "Дэлгэрэнгүй",
+    "Loading" : "Loading",
+    "Name" : "Нэр",
+    "Title" : "Цол/Албан тушаал",
     "Download" : "Татаж авах",
     "Delete" : "Устгах",
     "Groups" : "Багууд",
     "New contact" : "Шинэ харилцагч",
+    "No results" : "Үр дүн байхгүй",
+    "Last modified" : "Сүүлд өөрчилсөн",
     "Rename" : "Нэр солих",
+    "Enabled" : "Идэвхижүүлэх",
+    "Disabled" : "идэвхигүй",
     "Share with users or groups" : "Бусдад түгээх",
+    "can edit" : "засаж чадна",
+    "Address book name" : "Хаягийн дэвтрийн нэр",
     "First name" : "Нэр",
     "Last name" : "Овог",
+    "Display name" : "Харагдах нэр",
+    "Not grouped" : "Багт ороогүй",
     "Nickname" : "Товч нэр",
     "Detailed name" : "Дэлгэрэнгүй нэр",
     "Additional names" : "Нэмэлт нэрүүд",
     "Notes" : "Тэмдэглэл",
     "Website" : "Цахим хуудас",
+    "Location" : "Байршил",
     "Home" : "Гэр",
     "Work" : "Ажил",
     "Other" : "Бусад",
@@ -34,6 +46,9 @@ OC.L10N.register(
     "Fax" : "Факс",
     "Fax home" : "Гэрийн факс",
     "Fax work" : "Ажлын факс",
-    "Social network" : "Олон нийтийн сүлжээ"
+    "Social network" : "Олон нийтийн сүлжээ",
+    "Relative" : "Хамаарал",
+    "None" : "юу ч үгүй",
+    "Unknown" : "Үл танигдах зүйл"
 },
 "nplurals=2; plural=(n != 1);");
