@@ -2,10 +2,18 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Hubungi ",
+    "Loading" : "Loading",
+    "Name" : "Nama",
+    "Title" : "Judul",
+    "Download" : "Muat turun",
+    "Delete" : "Padam",
     "Groups" : "Kumpulan",
+    "Rename" : "Namakan",
+    "can edit" : "boleh mengubah",
     "Nickname" : "Nama Samaran",
     "Additional names" : "Nama tambahan",
     "Notes" : "Nota",
+    "Location" : "Lokasi",
     "Home" : "Rumah",
     "Work" : "Kerja",
     "Other" : "Lain",
