@@ -68,6 +68,7 @@ OC.L10N.register(
     "Suffix" : "Suffiks",
     "Notes" : "Notater",
     "Website" : "Nettsted",
+    "Location" : "Sted",
     "Federated Cloud ID" : "ID for sammenknyttet sky",
     "Home" : "Hjem",
     "Work" : "Jobb",
@@ -119,6 +120,7 @@ OC.L10N.register(
     "Male" : "Dame",
     "None" : "Ingen",
     "Unknown" : "Ukjent",
+    "Timezone" : "Tidssone",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt kunne ikke bli lest inn","{failed} kontakter kunne ikke bli lest inn"],
     "An error occurred" : "En feil oppstod"
 },
