@@ -3,14 +3,25 @@ OC.L10N.register(
     {
     "Contacts" : "Contactes",
     "All contacts" : "Totes los contactes",
+    "Details" : "Detalhs",
+    "Loading" : "Loading",
+    "Name" : "Nom",
+    "Title" : "Títol",
+    "Download" : "Telecargar",
+    "Delete" : "Suprimir",
     "Groups" : "Gropes",
     "New contact" : "Contacte novèl",
+    "Rename" : "Renomenar",
+    "Copy link" : "Copiar lo ligam",
+    "can edit" : "pòt modificar",
     "First name" : "Prenom",
     "Last name" : "Nom",
+    "Not grouped" : "Pas gropats",
     "Nickname" : "Escais",
     "Additional names" : "Noms suplementaris",
     "Notes" : "Nòtas",
     "Website" : "Site web",
+    "Location" : "Emplaçament",
     "Federated Cloud ID" : "Federated Cloud ID",
     "Home" : "Domicili",
     "Work" : "Professional(a)",
@@ -27,6 +38,9 @@ OC.L10N.register(
     "Mobile" : "Mobil",
     "Fax" : "Fax",
     "Pager" : "Messatgièr",
-    "Voice" : "Votz"
+    "Voice" : "Votz",
+    "Relative" : "Relatiu",
+    "None" : "Pas cap",
+    "Unknown" : "Desconegut"
 },
 "nplurals=2; plural=(n > 1);");
