@@ -5,18 +5,28 @@ OC.L10N.register(
     "All contacts" : "Todos os contactos",
     "Details" : "Detalhes",
     "Download picture" : "Transferir imagem",
+    "Loading" : "A carregar",
+    "Name" : "Nome",
+    "Title" : "Título",
     "Download" : "Transferir",
     "Delete" : "Apagar",
     "Groups" : "Grupos",
     "New contact" : "Novo contacto",
+    "No results" : "Sem resultados",
+    "Last modified" : "Última modificação",
     "Rename" : "Renomear",
     "Enabled" : "Ativada",
     "Disabled" : "Desactivado",
     "Copy link" : "Copiar hiperligação",
     "Share with users or groups" : "Partilhe com os utilizadores ou grupos",
+    "can edit" : "pode editar",
+    "Importing into" : "Importar para",
     "Import into" : "Importar para",
+    "Address book name" : "Nome do livro de endereços",
     "First name" : "Primeiro Nome",
     "Last name" : "Ultimo Nome",
+    "Display name" : "Nome de apresentação",
+    "Not grouped" : "Não agrupados",
     "Nickname" : "Alcunha",
     "Detailed name" : "Nome em detalhe",
     "Additional names" : "Nomes adicionais",
@@ -24,6 +34,7 @@ OC.L10N.register(
     "Suffix" : "Sufixo",
     "Notes" : "Notas",
     "Website" : "Site da Internet",
+    "Location" : "Localização:",
     "Federated Cloud ID" : "Id. da Nuvem Federada",
     "Home" : "Início",
     "Work" : "Emprego",
@@ -63,8 +74,12 @@ OC.L10N.register(
     "Colleague" : "Colega",
     "Manager" : "Gestor",
     "Assistant" : "Assistente",
+    "Contact" : "Contacto",
     "Gender" : "Género",
     "Female" : "Feminino",
-    "Male" : "Masculino"
+    "Male" : "Masculino",
+    "None" : "Nenhum",
+    "Unknown" : "Desconhecido",
+    "An error occurred" : "Ocorreu um erro"
 },
 "nplurals=2; plural=(n != 1);");
