@@ -4,18 +4,27 @@ OC.L10N.register(
     "Contacts" : "Contacte",
     "All contacts" : "Toate contactele",
     "Details" : "Detalii",
+    "Loading" : "Loading",
+    "Name" : "Nume",
+    "Title" : "Titlu",
     "Download" : "Descărcare",
     "Delete" : "Șterge",
     "Groups" : "Grupuri",
     "New contact" : "Contact nou ",
+    "No results" : "Niciun rezultat",
     "Rename" : "Redenumește",
     "Enabled" : "Activat",
     "Disabled" : "Dezactivat",
     "Copy link" : "Copiază linkul",
     "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
+    "can edit" : "poate edita",
+    "Importing into" : "Se importă în",
     "Import into" : "Importă în",
+    "Address book name" : "Numele listă de contacte",
     "First name" : "Prenume",
     "Last name" : "Nume",
+    "Display name" : "Nume afișat",
+    "Not grouped" : "Negrupate",
     "Nickname" : "Pseudonim",
     "Detailed name" : "Nume detaliat",
     "Additional names" : "Nume adiționale",
@@ -23,6 +32,7 @@ OC.L10N.register(
     "Suffix" : "Sufix",
     "Notes" : "Notă",
     "Website" : "Website",
+    "Location" : "Locație",
     "Federated Cloud ID" : "Federated Cloud ID",
     "Home" : "Acasă",
     "Work" : "Serviciu",
@@ -62,8 +72,11 @@ OC.L10N.register(
     "Colleague" : "Coleg",
     "Manager" : "Director",
     "Assistant" : "Asistent",
+    "Contact" : "Contact",
     "Gender" : "Sex",
     "Female" : "Femeie",
-    "Male" : "Bărbat"
+    "Male" : "Bărbat",
+    "None" : "Niciuna",
+    "Unknown" : "Necunoscut"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
