@@ -28,9 +28,11 @@ OC.L10N.register(
     "New contact" : "Nov stik",
     "Syntax error. Cannot open the contact." : "Napaka skladnje. Ni mogoče odpreti podatkov stika.",
     "No errors" : "Ni zaznanih napak",
+    "Open your browser console for more details" : "Več podrobnosti je izpisanih v konzoli brskalnika",
     "Select type" : "Izbor vrste",
     "Select Date" : "Izbor datuma",
     "Add contact in group" : "Dodaj stik v skupino",
+    "No results" : "Ni zadetkov",
     "Last modified" : "Nazadnje spremenjeno",
     "Select option" : "Izbor možnosti",
     "Rename" : "Preimenuj",
@@ -40,12 +42,18 @@ OC.L10N.register(
     "Can not copy" : "Ni mogoče kopirati!",
     "Copy link" : "Kopiraj povezavo",
     "Share with users or groups" : "Souporaba z uporabniki ali skupinami",
+    "No users or groups" : "Ni uporabnikov oziroma skupin",
+    "can edit" : "lahko ureja",
+    "Unable to delete the share." : "Ni mogoče izbrisati souporabe.",
+    "Unable to change permissions." : "Ni mogoče spremeniti dovoljenj.",
+    "Importing into" : "Uvažanje informacij",
     "Import into" : "Uvozi v",
     "Address book name" : "Ime imenika",
     "First name" : "Ime",
     "Last name" : "Priimek",
     "Display name" : "Prikazano ime",
     "Sort by {sorting}" : "Razvrsti po {sorting}",
+    "Not grouped" : "Brez skupine",
     "Nickname" : "Vzdevek",
     "Detailed name" : "Podrobno ime",
     "Additional names" : "Druga imena",
@@ -53,6 +61,7 @@ OC.L10N.register(
     "Suffix" : "Pripona",
     "Notes" : "Opombe",
     "Website" : "Spletna stran",
+    "Location" : "Mesto",
     "Federated Cloud ID" : "ID zveznega oblaka",
     "Home" : "Domači naslov",
     "Work" : "Službeni naslov",
@@ -72,7 +81,7 @@ OC.L10N.register(
     "Phone" : "Telefon",
     "Mobile" : "Mobilni telefon",
     "Work mobile" : "Službeni mobilni telefon",
-    "Home mobile" : "Domači mobilni telefon",
+    "Home mobile" : "Osebni mobilni telefon",
     "Fax" : "Faks",
     "Fax home" : "Domači faks",
     "Fax work" : "Službeni faks",
@@ -102,6 +111,7 @@ OC.L10N.register(
     "Male" : "Moški",
     "None" : "Brez",
     "Unknown" : "Neznano",
+    "Timezone" : "Časovni pas",
     "An error occurred" : "Prišlo je do napake."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
