@@ -43,14 +43,21 @@ OC.L10N.register(
     "Select type" : "Zgjidhni llojin",
     "Select Date" : "Zgjidhni Datën",
     "Add contact in group" : "Shto kontaktin në grup",
+    "No results" : "Asnjë rezultat",
+    "Last modified" : "Ndryshuar së fundmi",
     "Rename" : "Riemëro",
     "Enabled" : "I aktivizuar",
     "Disabled" : "I çaktivizuar",
     "Copy link" : "Kopjo linkun",
     "Share with users or groups" : "Nda me përdoruesit ose grupet",
+    "can edit" : "mund të modifikoni",
+    "Importing into" : "Duke u importuar në",
     "Import into" : "Importo tek ",
+    "Address book name" : "Emër libri adresash",
     "First name" : "Emër",
     "Last name" : "Mbiemër",
+    "Display name" : "Shfaq emrin",
+    "Not grouped" : "I pagrupuar",
     "Nickname" : "Nofkë",
     "Detailed name" : "Emri i hollësishëm",
     "Additional names" : "Emra shtesë",
@@ -58,6 +65,7 @@ OC.L10N.register(
     "Suffix" : "Prapashtesë",
     "Notes" : "Shënime",
     "Website" : "Faqe interneti",
+    "Location" : "Vendndodhje",
     "Federated Cloud ID" : "ID Federated Cloud",
     "Home" : "Kreu",
     "Work" : "Punë",
@@ -102,6 +110,8 @@ OC.L10N.register(
     "Co-worker" : "Koleg",
     "Gender" : "Gjinia",
     "Female" : "Femër",
-    "Male" : "Mashkull"
+    "Male" : "Mashkull",
+    "None" : "Asnjë",
+    "Unknown" : "I/E panjohur"
 },
 "nplurals=2; plural=(n != 1);");
