@@ -26,14 +26,20 @@ OC.L10N.register(
     "Addressbook" : "Адресна книга",
     "Groups" : "Групи",
     "New contact" : "Новий контакт",
+    "No results" : "Немає результатів",
     "Rename" : "Перейменувати",
     "Enabled" : "Увімкнено",
     "Disabled" : "Вимкнено",
     "Copy link" : "Копіювати посилання",
     "Share with users or groups" : "Поділитися з користувачем або групою",
+    "can edit" : "може редагувати",
+    "Importing into" : "Імпортування до",
     "Import into" : "Імпортувати до",
+    "Address book name" : "Назва адресної книги",
     "First name" : "Ім'я",
     "Last name" : "Прізвище",
+    "Display name" : "Ім'я для відображення",
+    "Not grouped" : "Не згруповані",
     "Nickname" : "Прізвисько",
     "Detailed name" : "Повне ім'я",
     "Additional names" : "Додаткові імена",
@@ -41,6 +47,7 @@ OC.L10N.register(
     "Suffix" : "Суфікс",
     "Notes" : "Нотатки",
     "Website" : "Web-сайт",
+    "Location" : "Місце",
     "Federated Cloud ID" : "Об'єднаний Хмарний Ідентіфікатор",
     "Home" : "Домашня адреса",
     "Work" : "Робота",
@@ -77,8 +84,13 @@ OC.L10N.register(
     "Sister" : "Сестра",
     "Friend" : "Друг",
     "Colleague" : "Колега",
+    "Contact" : "Контакт",
     "Gender" : "Стать",
     "Female" : "Жінка",
-    "Male" : "Чоловік"
+    "Male" : "Чоловік",
+    "None" : "Відсутній",
+    "Unknown" : "Невідомо",
+    "Timezone" : "Часовий пояс",
+    "An error occurred" : "Виникла помилка"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
