@@ -4,16 +4,27 @@ OC.L10N.register(
     "Contacts" : "Các danh bạ",
     "All contacts" : "Tất cả các tên liên lạc",
     "Details" : "Chi tiết",
+    "Loading" : "Đang tải",
+    "Name" : "Tên",
+    "Title" : "Tên",
     "Download" : "Tải về",
     "Delete" : "Xóa",
     "Groups" : "Nhóm",
     "New contact" : "Thêm liên lạc",
+    "No results" : "Không có kết quả",
     "Rename" : "Đổi tên",
+    "Enabled" : "Bật",
+    "Disabled" : "Tắt",
     "Copy link" : "Sao chép liên kết",
     "Share with users or groups" : "Chia sẻ với nhiều người sử dụng hoặc nhiều nhóm người sử dụng",
+    "can edit" : "Có thể chỉnh sửa",
+    "Importing into" : "Đang nhập vào",
     "Import into" : "Nhập vào",
+    "Address book name" : "Tên sổ địa chỉ",
     "First name" : "Tên",
     "Last name" : "Họ",
+    "Display name" : "Tên hiển thị",
+    "Not grouped" : "Không  nhóm",
     "Nickname" : "Biệt danh",
     "Detailed name" : "Tên chi tiết",
     "Additional names" : "Tên bổ sung",
@@ -21,6 +32,7 @@ OC.L10N.register(
     "Suffix" : "Hậu tố",
     "Notes" : "Ghi chép",
     "Website" : "Website",
+    "Location" : "Vị trí",
     "Federated Cloud ID" : "Federated Cloud ID",
     "Home" : "Nhà",
     "Work" : "Công việc",
@@ -59,6 +71,9 @@ OC.L10N.register(
     "Assistant" : "Trợ lý",
     "Gender" : "Giới tính",
     "Female" : "Nữ",
-    "Male" : "Nam"
+    "Male" : "Nam",
+    "None" : "Không có",
+    "Unknown" : "Không xác định",
+    "Timezone" : "Múi giờ"
 },
 "nplurals=1; plural=0;");
