@@ -4,18 +4,29 @@ OC.L10N.register(
     "Contacts" : "通訊錄",
     "All contacts" : "所有聯絡人",
     "Details" : "詳細資料",
+    "Loading" : "載入中",
+    "Name" : "名稱",
+    "Company" : "公司",
+    "Title" : "標題",
     "Download" : "下載",
     "Delete" : "刪除",
     "Groups" : "群組",
     "New contact" : "新聯絡人",
+    "No results" : "沒有符合搜尋的項目",
+    "Last modified" : "上一次修改",
     "Rename" : "重新命名",
     "Enabled" : "已啟用",
     "Disabled" : "已停用",
     "Copy link" : "複製連結",
     "Share with users or groups" : "與使用者或群組分享",
+    "can edit" : "允許編輯",
+    "Importing into" : "正匯入至",
     "Import into" : "匯入至",
+    "Address book name" : "通訊錄名稱",
     "First name" : "名",
     "Last name" : "姓",
+    "Display name" : "顯示名稱",
+    "Not grouped" : "未歸類",
     "Nickname" : "暱稱",
     "Detailed name" : "詳細名稱",
     "Additional names" : "別名/中間名",
@@ -23,6 +34,7 @@ OC.L10N.register(
     "Suffix" : "後綴",
     "Notes" : "筆記",
     "Website" : "網站",
+    "Location" : "地點",
     "Federated Cloud ID" : "雲端聯邦 ID",
     "Home" : "住家",
     "Work" : "工作",
@@ -62,8 +74,13 @@ OC.L10N.register(
     "Colleague" : "同事",
     "Manager" : "經理",
     "Assistant" : "助理",
+    "Contact" : "聯絡人",
     "Gender" : "性別",
     "Female" : "女性",
-    "Male" : "男性"
+    "Male" : "男性",
+    "None" : "無",
+    "Unknown" : "不明",
+    "Timezone" : "時區",
+    "An error occurred" : "發生錯誤"
 },
 "nplurals=1; plural=0;");
